Value

Enum Value 

pub enum Value {
    Single(String),
    Array(Vec<String>),
}
A single value or a list of values declared in the output of the alpm-pkgbuild-bridge script.

Both parser functions ensure that at least one value exists.

Variants



Single(String)

A single value.



Array(Vec<String>)

An array of values.

Implementations

Source

impl Value

pub fn as_vec(&self) -> Vec<&String>

Returns the values of &self in vector representation.

This is useful for values that may be available as both single values and arrays.

pub fn as_owned_vec(self) -> Vec<String>

Returns the values of self in vector representation.

This is useful for values that may be available as both single values and arrays.

pub fn has_value(&self) -> bool

Checks whether this holds a value.

Returns true if self is Value::Single (they always have a value set by definition), or if self is Value::Array and contains at least one element. Returns false in all other cases.

pub fn parse_next_value(input: &mut &str) -> ModalResult<String>

Recognizes a Value::Single in a string slice.

Calls Value::variable_character to handle escaped characters in input.

Examples
"This is a string value\" with escaped \\ characters"
Errors

Returns an error if no Value::Single is found in input.

pub fn variable_character(input: &mut &str) -> ModalResult<char>

Recognizes a single char in a string slice.

This allows for detecting escaped characters, such as \" or \\.

Consumes a single character and returns afterwards.

Errors

Returns an error if a stand-alone " or \ is encountered.