pub struct BridgeOutput {
pub package_base: HashMap<Keyword, Value>,
pub packages: HashMap<RawPackageName, HashMap<Keyword, ClearableValue>>,
pub functions: Vec<RawPackageName>,
}Expand description
Represents the raw parsed, but not yet typed output of the alpm-pkgbuild-bridge script.
Fields
package_base: HashMap<Keyword, Value>The map of all assigned keywords in the pkgbase section of the bridge output.
packages: HashMap<RawPackageName, HashMap<Keyword, ClearableValue>>The map of all assigned keywords in the package section of the bridge output.
The keywords are grouped by package name.
functions: Vec<RawPackageName>The list of all package function names that are declared in the bridge output.
Implementations
Sourceimpl BridgeOutput
impl BridgeOutput
Sourcepub fn from_file(pkgbuild_path: &Path) -> Result<Self, Error>
pub fn from_file(pkgbuild_path: &Path) -> Result<Self, Error>
Creates a BridgeOutput from a PKGBUILD at a given path, by calling the
alpm-pkgbuild-bridge script.
Sourcepub fn from_script_output(input: &str) -> Result<Self, Error>
pub fn from_script_output(input: &str) -> Result<Self, Error>
Creates a BridgeOutput from some alpm-pkgbuild-bridge script output.
This function is mostly exposed for testing, consider using Self::from_file.