Keyword

Struct Keyword 

pub struct Keyword {
    pub keyword: String,
    pub suffix: Option<String>,
}
A keyword (with an optional Architecture suffix) of a variable found in the output of the alpm-pkgbuild-bridge script.

Fields

keyword: String

The name of the keyword.

suffix: Option<String>

The optional _$suffix that indicates a specific architecture.

Implementations

Source

impl Keyword

pub fn simple<T: ToString>(keyword: T) -> Self

Creates a Keyword without an Architecture suffix from a string.