Module error
alpm_
pkgbuild
0.2.3
Module error
Module Items
Enums
In crate alpm_
pkgbuild
alpm_pkgbuild
Module
error
All error types that are exposed by this crate.
Enums

Error
The high-level error that can occur when using this crate.